import requests
import json
import easymaker
from easymaker.common import constants
from easymaker.common import utils
from easymaker.common import exceptions


class ApiSender:
    def __init__(self, region, appkey):
        self._easymakerApiUrl = constants.EASYMAKER_API_URL.format(region)
        self._appkey = appkey
        self._region = region
        utils.validate_region(self._region)

    def _isSuccessful(self, response):
        isSuccess = response['header']['isSuccessful']
        if not isSuccess:
            raise exceptions.EasyMakerError(response['header']['resultMessage'])
        return isSuccess

    def _get_headers(self):
        headers = {'X-Secret-Key': easymaker.easymaker_config.secret_key}
        return headers

    def get_flavor_list(self):
        response = requests.get("".join([self._easymakerApiUrl, '/v1.0/appkeys/{}/flavors'.format(self._appkey)])).json()
        self._isSuccessful(response)

        flavor_dict_list = []
        for flavor in response['flavorList']:
            flavor_dict_list.append({'id': flavor['id'], 'name': flavor['name']})
        return flavor_dict_list

    def run_training(self, body):
        response = requests.post("".join([self._easymakerApiUrl, '/v1.0/appkeys/{}/training'.format(self._appkey)]),
                                 data=json.dumps(body),
                                 headers=self._get_headers()).json()

        self._isSuccessful(response)
        return response
