import argparse
import easymaker
from easymaker.api.api_sender import ApiSender
from easymaker.common import environment_variables


def main():
    parser = argparse.ArgumentParser(prog='EasyMaker', description='EasyMaker Command-line interface.')
    parser.add_argument("--version", action='version', version=easymaker.__version__)

    parser.add_argument("--flavor", dest='flavor', action='store_true',
                        help='Supported flavor list, usage: python -m easymaker  --flavor --appkey APPKEY --region REGION')
    parser.add_argument("--appkey", dest='appkey')
    parser.add_argument("--region", dest='region')

    args = parser.parse_args()

    if args.flavor:
        region = args.region if args.region else environment_variables.region
        appkey = args.appkey if args.appkey else environment_variables.appkey

        api_sender = ApiSender(region, appkey)
        flavor_list = api_sender.get_flavor_list()
        for flavor in flavor_list:
            print(flavor['name'])


if __name__ == "__main__":
    main()
