# -*- coding: utf-8 -*-

import logging
from typing import Optional

from easymaker.common import utils
from easymaker.common import constants
from easymaker.api.api_sender import ApiSender

_LOGGER = logging.getLogger(__name__)


class _Config:
    """Stores common parameters and options for API calls."""

    def __init__(self):
        self._appkey = None
        self._region = None
        self._user_id = None
        self._secret_key = None

        self.api_sender = None

    def init(
            self,
            *,
            appkey: Optional[str] = None,
            region: Optional[str] = None,
            user_id: Optional[str] = None,
            secret_key: Optional[str] = None,
    ):
        """
        Args:
            appkey (str): easymaker appkey
            region (str): region (kr1, ..)
            user_id (str): nhn cloud user id (email)
            secret_key (str): easymaker secret key
        """
        _LOGGER.debug('EasyMaker Config init')
        if appkey:
            self._appkey = appkey
        if region:
            utils.validate_region(region)
            self._region = region
        if user_id:
            self._user_id = user_id
        if secret_key:
            self._secret_key = secret_key

        self.api_sender = ApiSender(region, appkey)

    @property
    def appkey(self) -> str:
        return self._appkey

    @property
    def region(self) -> str:
        return self._region or constants.DEFAULT_REGION

    @property
    def user_id(self) -> str:
        return self._user_id

    @property
    def secret_key(self) -> str:
        return self._secret_key


# global config to store init parameters: easymaker.init(appkey=..., region=...)
global_config = _Config()
